@@ -3,19 +3,18 @@ Box-Cox Transformer
 -------------------
 """
 
-from typing import Optional, Union, Sequence, Iterator, Tuple
-from scipy.stats import boxcox_normmax, boxcox
-from scipy.special import inv_boxcox
-import pandas as pd
+from typing import Iterator, Optional, Sequence, Tuple, Union
+
 import numpy as np
+import pandas as pd
+from scipy.special import inv_boxcox
+from scipy.stats import boxcox, boxcox_normmax
+
+from .fittable_data_transformer import FittableDataTransformer
+from .invertible_data_transformer import InvertibleDataTransformer
 
-from darts.timeseries import TimeSeries
-from darts.dataprocessing.transformers import (
-    FittableDataTransformer,
-    InvertibleDataTransformer,
-)
 from darts.logging import get_logger, raise_if
-
+from darts.timeseries import TimeSeries
 
 logger = get_logger(__name__)
 
@@ -44,11 +43,11 @@ class BoxCox(FittableDataTransformer, InvertibleDataTransformer):
         name
             A specific name for the transformer
         lmbda
-            The parameter :math:`\lambda` of the Box-Cox transform. If a single float is given, the same
-            :math:`\lambda` value will be used for all dimensions of the series, for all the series.
+            The parameter :math:`\\lambda` of the Box-Cox transform. If a single float is given, the same
+            :math:`\\lambda` value will be used for all dimensions of the series, for all the series.
             If a sequence is given, there is one value per component in the series. If a sequence of sequence
             is given, there is one value per component for all series.
-            If `None` given, will automatically find an optimal value of :math:`\lambda` (for each dimension
+            If `None` given, will automatically find an optimal value of :math:`\\lambda` (for each dimension
             of the time series, for each time series) using :func:`scipy.stats.boxcox_normmax`
             with ``method=optim_method``.
         optim_method
